/**
 * Augments ECC code words to given code words. The resulting words are
 * ready to be encoded in the matrix.
 *
 * The actual augmenting procedure follows JIS X 0510:2004 sec 8.7.
 * The code is simplified using the fact that the size of each code & ECC
 * blocks is almost the same; for example, when we have 4 blocks and 46 data words,
 * the number of code words in those blocks are 11, 11, 12, 12 respectively.
 *
 * @param {number[]} poly - The array of code words to which ECC words are to be augmented.
 * @param {number} blockNumber - The number of blocks into which the code words are divided.
 * @param {number[]} genPoly - The generator polynomial used for calculating ECC words.
 * @returns {number[]} The augmented array of code words ready for encoding in the matrix.
 */
export declare function augmentECCs(poly: number[], blockNumber: number, genPoly: number[]): number[];
